@@ -131,6 +131,7 @@ class DuckDB(Dialect):
         exp.DateAdd: _date_add,
         exp.DateDiff: lambda self, e: f"{self.sql(e, 'this')} - {self.sql(e, 'expression')}",
         exp.DateStrToDate: lambda self, e: f"CAST({self.sql(e, 'this')} AS DATE)",
+        exp.Explode: lambda self, e: f"UNNEST({self.sql(e, 'this')})",
         exp.Quantile: lambda self, e: f"QUANTILE({self.sql(e, 'this')}, {self.sql(e, 'quantile')})",
         exp.RegexLike: lambda self, e: f"REGEXP_MATCHES({self.sql(e, 'this')}, {self.sql(e, 'expression')})",
         exp.StrToTime: lambda self, e: f"STRPTIME({self.sql(e, 'this')}, {self.sql(e, 'format')})",
@@ -165,6 +166,7 @@ class DuckDB(Dialect):
         "STRFTIME": exp.TimeToStr.from_arg_list,
         "STRPTIME": exp.StrToTime.from_arg_list,
         "TO_TIMESTAMP": exp.TimeStrToTime.from_arg_list,
+        "UNNEST": exp.Explode.from_arg_list,
     }
 
 
@@ -239,6 +241,7 @@ class Hive(Dialect):
         exp.If: _if_sql,
         exp.JSONPath: lambda self, e: f"GET_JSON_OBJECT({self.sql(e, 'this')}, {self.sql(e, 'path')})",
         exp.Quantile: lambda self, e: f"PERCENTILE({self.sql(e, 'this')}, {self.sql(e, 'quantile')})",
+        exp.SetAgg: lambda self, e: f"COLLECT_SET({self.sql(e, 'this')})",
         exp.StrPosition: lambda self, e: f"LOCATE({csv(self.sql(e, 'substr'), self.sql(e, 'this'), self.sql(e, 'position'))})",
         exp.StrToTime: _str_to_time,
         exp.StrToUnix: _str_to_unix,
@@ -290,6 +293,7 @@ class Hive(Dialect):
         "MAP": _parse_map,
         "MONTH": lambda args: exp.Month(this=exp.TsOrDsToDate.from_arg_list(args)),
         "PERCENTILE": exp.Quantile.from_arg_list,
+        "COLLECT_SET": exp.SetAgg.from_arg_list,
         "SIZE": exp.ArraySize.from_arg_list,
         "TO_DATE": exp.TsOrDsToDateStr.from_arg_list,
         "UNIX_TIMESTAMP": lambda args: exp.StrToUnix(
@@ -338,6 +342,12 @@ class Presto(Dialect):
             return f"ARRAY_JOIN(ARRAY[{csv(*(self.sql(e) for e in args))}], {sep})"
         return f"ARRAY_JOIN({self.sql(args[0])}, {sep})"
 
+    def _datatype_sql(self, expression):
+        sql = self.datatype_sql(expression)
+        if expression.this == exp.DataType.Type.TIMESTAMPTZ:
+            sql = f"{sql} WITH TIME ZONE"
+        return sql
+
     def _fileformat_sql(self, expression):
         file_format = self.sql(expression, "this").replace(self.quote, "")
         if file_format:
@@ -382,6 +392,7 @@ class Presto(Dialect):
         exp.DataType.Type.FLOAT: "REAL",
         exp.DataType.Type.BINARY: "VARBINARY",
         exp.DataType.Type.TEXT: "VARCHAR",
+        exp.DataType.Type.TIMESTAMPTZ: "TIMESTAMP",
     }
 
     transforms = {
@@ -397,6 +408,7 @@ class Presto(Dialect):
         exp.BitwiseXor: lambda self, e: f"BITWISE_XOR({self.sql(e, 'this')}, {self.sql(e, 'expression')})",
         exp.Case: _case_if_sql,
         exp.ConcatWs: _concat_ws_sql,
+        exp.DataType: _datatype_sql,
         exp.DateAdd: lambda self, e: f"""DATE_ADD({self.sql(e, 'unit') or "'day'"}, {self.sql(e, 'expression')}, {self.sql(e, 'this')})""",
         exp.DateDiff: lambda self, e: f"""DATE_DIFF({self.sql(e, 'unit') or "'day'"}, {self.sql(e, 'expression')}, {self.sql(e, 'this')})""",
         exp.DateStrToDate: lambda self, e: f"DATE_PARSE({self.sql(e, 'this')}, '%Y-%m-%d')",
