@@ -462,6 +462,8 @@ class Null(Expression):
 
 
 class DataType(Expression):
+    arg_types = {"this": True, "expressions": False}
+
     class Type(AutoName):
         CHAR = auto()
         TEXT = auto()
@@ -805,6 +807,10 @@ class Exp(Func):
     pass
 
 
+class Explode(Func):
+    pass
+
+
 class Floor(Func):
     pass
 
@@ -887,6 +893,10 @@ class Round(Func):
     arg_types = {"this": True, "decimals": False}
 
 
+class SetAgg(AggFunc):
+    pass
+
+
 class StrPosition(Func):
     arg_types = {"this": True, "substr": True, "position": False}
 
